@@ -21,14 +21,13 @@
 import math
 import os
 import re
-from datetime import datetime
 from pathlib import Path
 
 import pyben
 from PySide6.QtCore import Qt, Signal
-from PySide6.QtGui import QIcon
 from PySide6.QtWidgets import (QGridLayout, QLabel, QLineEdit, QPushButton,
-                               QTreeWidget, QTreeWidgetItem, QWidget)
+                               QTreeWidget, QTreeWidgetItem, QVBoxLayout,
+                               QWidget)
 
 from torrentfileQt.utils import browse_torrent, get_icon
 
@@ -43,7 +42,7 @@ class TreeWidget(QTreeWidget):
         The widget containing this widget.
     """
 
-    itemReady = Signal([str, str])
+    itemReady = Signal(str, str)
 
     def __init__(self, parent=None):
         """Construct for tree widget."""
@@ -75,19 +74,19 @@ class TreeWidget(QTreeWidget):
                 if i + 1 == len(partials):
                     _, suffix = os.path.splitext(partial)
                     if suffix in [".mp4", ".mkv"]:
-                        iconpath = QIcon(get_icon("video"))
+                        iconpath = get_icon("video")
                     elif suffix in [".rar", ".zip", ".7z", ".tar", ".gz"]:
-                        iconpath = QIcon(get_icon("archive"))
+                        iconpath = get_icon("archive")
                     elif re.match(r"\.r\d+", suffix):
-                        iconpath = QIcon(get_icon("archive"))
+                        iconpath = get_icon("archive")
                     elif suffix in [".wav", ".mp3", ".flac", ".m4a", ".aac"]:
-                        iconpath = QIcon(get_icon("music"))
+                        iconpath = get_icon("music")
                     else:
-                        iconpath = QIcon(get_icon("file"))
+                        iconpath = get_icon("file")
                     item.setLength(length)
                 else:
-                    iconpath = QIcon(get_icon("folder"))
-                icon = QIcon(iconpath)
+                    iconpath = get_icon("folder")
+                icon = iconpath
                 item.setIcon(0, icon)
                 item.setText(1, partial)
                 tree["widget"].addChild(item)
@@ -108,7 +107,7 @@ class TreeItem(QTreeWidgetItem):
     def setLength(self, length):
         """Set length leaf for tree branches."""
         child = TreeItem(0)
-        icon = QIcon(QIcon(get_icon("scale")))
+        icon = get_icon("scale")
         child.setIcon(0, icon)
         child.setText(1, f"Size: {length} (bytes)")
         self.setExpanded(True)
@@ -122,8 +121,16 @@ class InfoWidget(QWidget):
         """Construct and organize Torrent info tab."""
         super().__init__(parent=parent)
         self.window = parent.window
-        self.layout = QGridLayout()
-        self.setLayout(self.layout)
+        self.setObjectName("infoTab")
+        self.setAttribute(Qt.WA_StyledBackground, True)
+        self.centralWidget = QWidget(self)
+        self.centralLayout = QVBoxLayout(self)
+        mainLabel = QLabel("Torrent File Info")
+        mainLabel.setAlignment(Qt.AlignmentFlag.AlignCenter)
+        mainLabel.setObjectName("infoMainLabel")
+        self.centralLayout.addWidget(mainLabel)
+        self.centralLayout.addWidget(self.centralWidget)
+        self.layout = QGridLayout(self.centralWidget)
 
         # Labels
         self.pathLabel = QLabel("Path: ", parent=self)
@@ -179,6 +186,7 @@ class InfoWidget(QWidget):
         self.layout.addWidget(self.contentsLabel, 12, 0, 1, 1)
         self.layout.addWidget(self.contentsTree, 12, 1, 4, -1)
         self.selectButton = SelectButton("Select Torrent", parent=self)
+        self.selectButton.selected.connect(self.torrent_selected)
         self.layout.addWidget(self.selectButton, 17, 0, -1, -1)
         self.pathLabel.setObjectName("pathLabel")
         self.pathEdit.setObjectName("pathEdit")
@@ -237,6 +245,11 @@ class InfoWidget(QWidget):
         for label in labels:
             label.setVisible(True)
 
+    def torrent_selected(self, path):
+        """Trigger button click for saving path information."""
+        kws = format_data(path)
+        self.fill(**kws)
+
     def dragEnterEvent(self, event):
         """Drag enter event for widget."""
         if event.mimeData().hasUrls:
@@ -255,8 +268,8 @@ class InfoWidget(QWidget):
 
     def dropEvent(self, event):
         """Accept drop event for info widgit."""
-        urls = event.mimeData().urls()
-        path = urls[0].toLocalFile()
+        path_urls = event.mimeData().urls()
+        path = path_urls[0].toLocalFile()
         if os.path.exists(path):
             kws = format_data(path)
             self.fill(**kws)
@@ -323,17 +336,18 @@ class InfoWidget(QWidget):
 class SelectButton(QPushButton):
     """Button for choosing the torrent file."""
 
+    selected = Signal(str)
+
     def __init__(self, text, parent=None):
         """Construct for select button."""
         super().__init__(text, parent=parent)
         self.pressed.connect(self.selectTorrent)
         self.setCursor(Qt.CursorShape.PointingHandCursor)
 
-    def selectTorrent(self, path=None):
+    def selectTorrent(self):
         """Collect torrent information and send to the screen for display."""
-        path = browse_torrent(self, path)
-        kws = format_data(path)
-        self.parent().fill(**kws)
+        path = browse_torrent(self)
+        self.selected.emit(path)
 
 
 class InfoLineEdit(QLineEdit):
@@ -404,9 +418,7 @@ def format_data(path):
     keywords["length"] = size
 
     if "creation date" in meta:
-        date = datetime.fromtimestamp(meta["creation date"])
-        text = date.strftime("%B %d, %Y %H:%M")
-        keywords["creation_date"] = text
+        keywords["creation_date"] = str(meta["creation date"])
     else:
         keywords["creation_date"] = ""
 
@@ -421,12 +433,12 @@ def denom(num):
     """Determine appropriate denomination for size of file."""
     txt = str(num)
     if int(num) < 1000:
-        return txt
+        return txt  # pragma: nocover
     if 1000 <= num <= 999999:
         return "".join([txt[:-3], ".", txt[-3], "KB"])
-    if 1_000_000 <= num < 1_000_000_000:
+    if 1_000_000 <= num < 1_000_000_000:  # pragma: nocover
         return "".join([txt[:-6], ".", txt[-6], "MB"])
-    return "".join([txt[:-9], ".", txt[-9], "GB"])
+    return "".join([txt[:-9], ".", txt[-9], "GB"])  # pragma: nocover
 
 
 def pretty_int(num):
